@@ -175,7 +175,6 @@ gnome_druid_instance_init (GnomeDruid *druid)
 	GTK_WIDGET_SET_FLAGS (druid->back, GTK_CAN_DEFAULT);
 	druid->next = gtk_button_new_from_stock (GTK_STOCK_GO_FORWARD);
 	GTK_WIDGET_SET_FLAGS (druid->next, GTK_CAN_DEFAULT);
-	GTK_WIDGET_SET_FLAGS (druid->next, GTK_HAS_FOCUS);
 	druid->cancel = gtk_button_new_from_stock (GTK_STOCK_CANCEL);
 	GTK_WIDGET_SET_FLAGS (druid->cancel, GTK_CAN_DEFAULT);
 	druid->finish = gtk_button_new_from_stock (GTK_STOCK_APPLY);
@@ -228,6 +227,8 @@ gnome_druid_instance_init (GnomeDruid *druid)
 			  G_CALLBACK (gnome_druid_next_callback), druid);
 	g_signal_connect (druid->help, "clicked",
 			  G_CALLBACK (gnome_druid_help_callback), druid);
+
+	gtk_widget_grab_focus (druid->next);
 }
 
 
@@ -663,7 +664,16 @@ gnome_druid_back_callback (GtkWidget *button, GnomeDruid *druid)
 	/* Make sure that we have a next list item */
 	list = g_list_find (druid->_priv->children, druid->_priv->current);
 	g_return_if_fail (list->prev != NULL);
-	gnome_druid_set_page (druid, GNOME_DRUID_PAGE (list->prev->data));
+
+	list = list->prev;
+	while (list != NULL &&
+	       ! GTK_WIDGET_VISIBLE (list->data))
+		list = list->prev;
+	
+	if ( ! list)
+		return;
+
+	gnome_druid_set_page (druid, GNOME_DRUID_PAGE (list->data));
 }
 static void
 gnome_druid_next_callback (GtkWidget *button, GnomeDruid *druid)
